package com.ruoyi.web.controller.clock;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.DutySchedule;
import com.ruoyi.system.service.IDutyScheduleService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 上班时间配置Controller
 *
 * @author ruoyi
 * @date 2024-08-07
 */
@RestController
@RequestMapping("/system/schedule")
public class DutyScheduleController extends BaseController {
    @Autowired
    private IDutyScheduleService dutyScheduleService;

    /**
     * 查询上班时间配置列表
     */
    @PreAuthorize("@ss.hasPermi('system:schedule:list')")
    @GetMapping("/list")
    public TableDataInfo list(DutySchedule dutySchedule) {
        startPage();
        List<DutySchedule> list = dutyScheduleService.selectDutyScheduleList(dutySchedule);
        return getDataTable(list);
    }

    /**
     * 导出上班时间配置列表
     */
    @PreAuthorize("@ss.hasPermi('system:schedule:export')")
    @Log(title = "上班时间配置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DutySchedule dutySchedule) {
        List<DutySchedule> list = dutyScheduleService.selectDutyScheduleList(dutySchedule);
        ExcelUtil<DutySchedule> util = new ExcelUtil<DutySchedule>(DutySchedule.class);
        util.exportExcel(response, list, "上班时间配置数据");
    }

    /**
     * 获取上班时间配置详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:schedule:query')")
    @GetMapping(value = "/{dutyId}")
    public AjaxResult getInfo(@PathVariable("dutyId") Long dutyId) {
        return success(dutyScheduleService.selectDutyScheduleByDutyId(dutyId));
    }

    /**
     * 新增上班时间配置
     */
    @PreAuthorize("@ss.hasPermi('system:schedule:add')")
    @Log(title = "上班时间配置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DutySchedule dutySchedule) {
        return toAjax(dutyScheduleService.insertDutySchedule(dutySchedule));
    }

    /**
     * 修改上班时间配置
     */
    @PreAuthorize("@ss.hasPermi('system:schedule:edit')")
    @Log(title = "上班时间配置", businessType = BusinessType.UPDATE)
    @PostMapping("/put")
    public AjaxResult edit(@RequestBody DutySchedule dutySchedule) {
        return toAjax(dutyScheduleService.updateDutySchedule(dutySchedule));
    }

    /**
     * 删除上班时间配置
     */
    @PreAuthorize("@ss.hasPermi('system:schedule:remove')")
    @Log(title = "上班时间配置", businessType = BusinessType.DELETE)
    @GetMapping("/delete/{dutyIds}")
    public AjaxResult remove(@PathVariable Long[] dutyIds) {
        return toAjax(dutyScheduleService.deleteDutyScheduleByDutyIds(dutyIds));
    }
}
