package com.ruoyi.system.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.DutyScheduleMapper;
import com.ruoyi.system.domain.DutySchedule;
import com.ruoyi.system.service.IDutyScheduleService;

/**
 * 上班时间配置Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-08-07
 */
@Service
public class DutyScheduleServiceImpl implements IDutyScheduleService 
{
    @Autowired
    private DutyScheduleMapper dutyScheduleMapper;

    /**
     * 查询上班时间配置
     * 
     * @param dutyId 上班时间配置主键
     * @return 上班时间配置
     */
    @Override
    public DutySchedule selectDutyScheduleByDutyId(Long dutyId)
    {
        return dutyScheduleMapper.selectDutyScheduleByDutyId(dutyId);
    }

    /**
     * 查询上班时间配置列表
     * 
     * @param dutySchedule 上班时间配置
     * @return 上班时间配置
     */
    @Override
    public List<DutySchedule> selectDutyScheduleList(DutySchedule dutySchedule)
    {
        return dutyScheduleMapper.selectDutyScheduleList(dutySchedule);
    }

    /**
     * 新增上班时间配置
     * 
     * @param dutySchedule 上班时间配置
     * @return 结果
     */
    @Override
    public int insertDutySchedule(DutySchedule dutySchedule)
    {
        dutySchedule.setCreateTime(DateUtils.getNowDate());
        return dutyScheduleMapper.insertDutySchedule(dutySchedule);
    }

    /**
     * 修改上班时间配置
     * 
     * @param dutySchedule 上班时间配置
     * @return 结果
     */
    @Override
    public int updateDutySchedule(DutySchedule dutySchedule)
    {
        dutySchedule.setUpdateTime(DateUtils.getNowDate());
        return dutyScheduleMapper.updateDutySchedule(dutySchedule);
    }

    /**
     * 批量删除上班时间配置
     * 
     * @param dutyIds 需要删除的上班时间配置主键
     * @return 结果
     */
    @Override
    public int deleteDutyScheduleByDutyIds(Long[] dutyIds)
    {
        return dutyScheduleMapper.deleteDutyScheduleByDutyIds(dutyIds);
    }

    /**
     * 删除上班时间配置信息
     * 
     * @param dutyId 上班时间配置主键
     * @return 结果
     */
    @Override
    public int deleteDutyScheduleByDutyId(Long dutyId)
    {
        return dutyScheduleMapper.deleteDutyScheduleByDutyId(dutyId);
    }
}
